@@ -1,11 +1,10 @@
 import winreg
 
-_file_types = [".jpg", ".jpeg", ".png", ".bmp"]
-
+import downscale_image
 
 def register_downscale_commands(path_to_program, args):
     """Register 'Downscale image' as right click option for each of _file_types to call program."""
-    for file_type in [rf"Software\Classes\SystemFileAssociations\{ext}\shell" for ext in _file_types]:
+    for file_type in [rf"Software\Classes\SystemFileAssociations\{ext}\shell" for ext in downscale_image.SUPPORTED_FILE_EXTENSIONS]:
         _set_run_key(file_type + r"\DownscaleImage", "Downscale image")
         _set_run_key(file_type + r"\DownscaleImage\command", rf'"{path_to_program}"' + " " + " ".join(args))
 
